@@ -1,3 +1,3 @@
-#define UTS_RELEASE "2.6.15-plamoUP"
+#define UTS_RELEASE "2.6.15.4-plamoUP"
 #define LINUX_VERSION_CODE 132623
 #define KERNEL_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
